@@ -1,16 +1,16 @@
 # coding=utf-8
 
-"""An interface to surgerycore-procrustes for the BARD application"""
+""" Calls sksurgerycore Orthogonal Procrustes for the BARD application. """
 
 import numpy as np
 from sksurgerycore.algorithms.procrustes import orthogonal_procrustes
 
 
 def run_procrustes(fixed_points_file, moving_points_file):
-    """ Shows how to use surgery-cores procrustes
-    function, we could get the students to implement this?
     """
-
+    Shows how to use sksurgerycore's orthogonal procrustes
+    function. We could get the students to implement this?
+    """
     moving_points = np.loadtxt(moving_points_file)
     fixed_points = np.loadtxt(fixed_points_file)
 
