@@ -4,16 +4,23 @@
 
 import sys
 from PySide2.QtWidgets import QApplication
+from sksurgerycore.configuration.configuration_manager import \
+        ConfigurationManager
 from sksurgerybard.widgets.bard_overlay_app import BARDOverlayApp
 
 
-def run_demo(config_file):
+def run_demo(config_file, calib_dir):
 
     """ Prints command line args, and launches main screen."""
 
     app = QApplication([])
 
-    viewer = BARDOverlayApp(config_file)
+    configuration = None
+    if config_file is not None:
+        configurer = ConfigurationManager(config_file)
+        configuration = configurer.get_copy()
+
+    viewer = BARDOverlayApp(configuration, calib_dir)
 
     viewer.start()
 
